<template>
    <div>
        <v-container style="margin-bottom: 5rem">
            <v-fade-transition>
                <v-row dense class="d-flex child-flex" :gutter="12">
                    <v-col v-for="(file, index) in files" :key="files.title" cols="12" md="3" sm="4" xs="4">
                        <v-card>
                            <v-img :src="imageUrl(file)" class="white--text align-end"
                                   gradient="to bottom, rgba(0,0,0,.1), rgba(0,0,0,.5)"
                                   height="150px">
                                <v-card-title class="text-subtitle-1" v-text="file.label"></v-card-title>
                            </v-img>
                            <v-card-actions>
                                <v-chip color="primary" text-color="white" x-small>
                                    {{ file.type }}/{{ fileExt(file.url) }}
                                </v-chip>
                                <v-spacer></v-spacer>
                                <v-tooltip top v-if="file.type === 'image'">
                                    <template v-slot:activator="{ on, attrs }">
                                        <v-btn icon v-bind="attrs" v-on="on">
                                            <v-icon>mdi-crop</v-icon>
                                        </v-btn>
                                    </template>
                                    <span>Recadrage-Redimensionner</span>
                                </v-tooltip>
                                <v-tooltip top>
                                    <template v-slot:activator="{ on, attrs }">
                                        <v-btn icon v-bind="attrs" v-on="on" @click="deleteMediaConfirmed(file, index)">
                                            <v-icon>mdi-delete</v-icon>
                                        </v-btn>
                                    </template>
                                    <span>Supprimer le fichier</span>
                                </v-tooltip>
                                <v-tooltip top>
                                    <template v-slot:activator="{ on, attrs }">
                                        <v-btn icon v-bind="attrs" v-on="on" @click="editMedia(file)">
                                            <v-icon>mdi-pencil</v-icon>
                                        </v-btn>
                                    </template>
                                    <span>Éditer le fichier</span>
                                </v-tooltip>
                                <v-tooltip top>
                                    <template v-slot:activator="{ on, attrs }">
                                        <v-btn icon v-bind="attrs" v-on="on" @click="copyToClipboard(file.full_path)">
                                            <v-icon>mdi-content-copy</v-icon>
                                        </v-btn>
                                    </template>
                                    <span>Copier le lien</span>
                                </v-tooltip>
                            </v-card-actions>
                        </v-card>
                    </v-col>
                </v-row>
            </v-fade-transition>
        </v-container>
    </div>
</template>

<script>
import MediaLayout from './Media.vue'
import DashboardLayout from "../../Components/Layouts/Dashboard.vue";
export default {
    name: "Index",
    layout: [DashboardLayout, MediaLayout],
    props: {
    },
    data() {
        return {
            files: this.$page.props.files,
            directories: this.$page.props.directories,
            edit: {
                label: '',
                id: ''
            },
            loading: false,
            loadingMedia: false,
        }
    },
    watch: {},
    methods: {
        appendUploads(data) {
            this.files.splice(this.files.length, 0, ...data)
        },
        checkImage(file) {
            return true /*file.type.startsWith('image') || file.thumbnail > 0 || file.url.endsWith('pdf') ||
                file.url.endsWith('doc') || file.url.endsWith('docx') || file.url.endsWith('xls') ||
                file.url.endsWith('xlsx')*/
        },
        imageUrl(file) {
            if (file.type === 'image') {
                return file.url
            }
            if (file.url.endsWith('pdf')) {
                return file.thumbnail_full_path || `/assets/img/icons/${this.fileExt(file.url)}.png`
            }
            if (file.type === 'audio' || file.type === 'video') {
                return `/assets/img/icons/${file.type}.png`
            }
            if (/[^.]+$/.exec(file.url).toString().startsWith('doc')) {
                return `/assets/img/icons/${this.fileExt(file.url)}.png`
            }
            return file.thumbnail_full_path || `/assets/img/icons/${this.fileExt(file.url)}.png`
        },
        fileExt(url) {
            let ext = /[^.]+$/.exec(url)
            return ext.length ? ext[0] : ''
        },
        copyToClipboard(cp) {
            navigator.clipboard.writeText(cp).then(() => {
            }, () => {
            })
        },
        deleteMediaConfirmed(item, index) {
            this._confirmDialog({
                confirm: () => {
                    this.loadingMedia = true
                    axios.post(this.$route('media.delete', {media: this.files[index].id}))
                        .then(res => res.data)
                        .then(data => {
                            if (data.status === 'success') {
                                this.files.splice(index, 1)
                                this.closeDelete()
                            }
                        })
                        .catch(err => {
                        })
                        .then(() => (this.loadingMedia = false))
                }
            })

        },
        editMedia(media) {
            this.edit.label = media.label;
            this.edit.id = media.id;
            this.$nextTick(() => {
                this.$refs.editMedia.$refs.input.select()
            })
        },
        updateMedia() {
            this.loading = true
            axios.post(this.$route('media.update', {media: this.edit.id}), this.edit)
                .then(res => res.data)
                .then(data => {
                    if (data.status === 'success') {
                        this.files.find(f => f.id === this.edit.id).label = data.data.label
                        this.closeEditDialog()
                    }
                })
                .catch(err => {
                })
                .then(() => (this.loading = false))
        },
        closeEditDialog() {
            this.edit.id = null
        }
    },
    mounted() {
        this.$on('uploaded', function () {
            console.log('refresh this page')
        })
    }
}
</script>

<style scoped>

</style>
